#!/usr/bin/python
"""
    Provides a class to encapsulate MythTV Storage Groups.
"""
try:
    from MythTV.MythLog import *
    from MythTV.MythDB import *
except:
    print "MythStorage module cannot be initialized."

import os, string

# create logging object
log = MythLog(CRITICAL, '#%(levelname)s - %(message)s', 'MythStorage')

class MythStorage(MythDB):
    def __init__(self):
        self.db = MythDB()
    def GetStorageDirs(self, host = 'localhost'):
        """
        Get the list of storage directories.
        """
        
        query = """SELECT DISTINCT dirname FROM storagegroup
                   WHERE hostname=%s
        """
        cursor = self.db.cursor()
        cursor.execute(query, (host))
        rows = cursor.fetchall()
        if rows:
            return rows
        else:
            return None
        
        cursor.close()

    def findRecordingDir(self, basename, host):
        """
        Find the directory which contains the given file.
        """
        rows = self.GetStorageDirs(host)
        for row in rows:
            if os.path.exists(row[0] + basename):
                return row[0]
                break
        return None

    def findRecordingFile(self, basename, host):
        """
        Find the full pathname of the given file.
        """
        rows = self.GetStorageDirs(host)
        for row in rows:
            if os.path.exists(row[0] + basename):
                return row[0] + basename
                break
        return None
            


if __name__ == '__main__':
    banner = "'mst' is a MythStorage instance."
    try:
            import readline, rlcompleter
    except:
            pass
    else:
            readline.parse_and_bind("tab: complete")
            banner = banner + " TAB completion is available."
    mst = MythStorage(sys.argv[1:])
    namespace = globals().copy()
    namespace.update(locals())
    code.InteractiveConsole(namespace).interact(banner)
    
